@@ -1,11 +1,29 @@
+# Copyright 2021 Agnostiq Inc.
+#
+# This file is part of Covalent.
+#
+# Licensed under the GNU Affero General Public License 3.0 (the "License").
+# A copy of the License may be obtained with this software package or at
+#
+#      https://www.gnu.org/licenses/agpl-3.0.en.html
+#
+# Use of this file is prohibited except in compliance with the License. Any
+# modifications or derivative works of this file must retain this copyright
+# notice, and modified files must contain a notice indicating that they have
+# been altered from the originals.
+#
+# Covalent is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE. See the License for more details.
+#
+# Relief from the License may be granted by purchasing a commercial license.
+
 import os
-from pathlib import Path
 from subprocess import PIPE, CalledProcessError, Popen
 from typing import Optional
 
-from covalent._file_transfer import File
-from covalent._file_transfer.enums import FileSchemes, FileTransferStrategyTypes
-from covalent._file_transfer.strategies.transfer_strategy_base import FileTransferStrategy
+from .. import File
+from .transfer_strategy_base import FileTransferStrategy
 
 
 class Rsync(FileTransferStrategy):
